@@ -89,11 +89,7 @@ Q_SIGNALS:
     void timeZoneChanged();
 
 protected:
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    void geometryChanged(const QRectF &newGeometry, const QRectF &oldGeometry) override;
-#else
     void geometryChange(const QRectF &newGeometry, const QRectF &oldGeometry) override;
-#endif
 
 private:
     void clear();
